@@ -44,23 +44,28 @@
 #' \dontrun{
 #' compet <- "ACB"
 #' df <- do_join_games_bio(compet, acb_games_1718, acb_players_1718)
+#' 
 #' df1 <- do_add_adv_stats(df)
+#' 
 #' df2 <- do_stats(df1, "Total", "2017-2018", compet, "Regular Season")
+#' 
 #' # When choosing a subset of stats, follow the order in which they appear
 #' # in the data frame.
 #' stats <- c("GP", "MP", "PTS", "FGA", "FGPerc", "ThreePA", "ThreePPerc", 
 #'            "FTA", "FTPerc", "TRB", "ORB", "AST", "STL", "TOV")
+#' 
 #' df2_1 <- df2[, c(1:5, which(colnames(df2) %in% stats), 46:49)]
+#' 
 #' descr_stats <- c("Games played", "Minutes played", "Points", 
 #'                 "Field goals attempted", "Field goals percentage", 
 #'                 "3-point field goals attempted", "3-point percentage", 
 #'                 "FTA: Free throws attempted", "Free throws percentage", 
 #'                 "Total rebounds", "Offensive rebounds", 
 #'                 "Assists", "Steals", "Turnovers")
+#' 
 #' get_bubble_plot(df2_1, "Abalde, Alberto", descr_stats, 6, 10, 12)
 #' }
 #' 
-#' @importFrom Anthropometry percentilsArchetypoid
 #' @importFrom ggplot2 geom_col geom_vline geom_hline coord_polar scale_color_grey
 #' @importFrom ggplot2 scale_y_continuous element_rect scale_fill_manual guides
 #' @importFrom grid unit
@@ -77,7 +82,7 @@ get_bubble_plot <- function(df_stats, player, descr_stats, size_text, size_text_
     select(-c(Name, Team, CombinID, Position, Nationality, 
               Season, Compet, Type_season, Type_stats)) 
   
-  percs <- sapply(1:dim(df_stats1)[2], percentilsArchetypoid, 
+  percs <- sapply(1:dim(df_stats1)[2], Anthropometry::percentilsArchetypoid, 
                   which(df_stats$Name == player), df_stats1, 0)
   
   df_cp <- data.frame(player = player,
@@ -101,10 +106,8 @@ get_bubble_plot <- function(df_stats, player, descr_stats, size_text, size_text_
     geom_col(alpha = 0.5, width = 1, color = "white") + 
     scale_color_grey(labels = labs, end = 0) +
     scale_fill_manual(values = cols_ggplot[percs_player]) +
-    geom_hline(yintercept = seq(0, 4, by = 1), 
-               colour = "#949494", size = 0.5, lty = 3) + #949494 is dark grey.
-    geom_vline(xintercept = seq(0.5, nrow(df_cp), 1), 
-               colour = "#949494", size = 0.4, lty = 1) +
+    geom_hline(yintercept = seq(0, 4, by = 1), colour = "#949494", linewidth = 0.5, lty = 3) + #949494 is dark grey.
+    geom_vline(xintercept = seq(0.5, nrow(df_cp), 1), colour = "#949494", linewidth = 0.4, lty = 1) +
     facet_wrap(~player) +
     coord_polar() + 
     scale_y_continuous(limits = c(0, 4), breaks = c(1, 2, 3, 4)) + 
